
rm(list = setdiff(ls(),c("PFAD","print.T1","print.T2")))
options(stringsAsFactors = F)

if("reshape" %in% rownames(installed.packages()) == F) install.packages("reshape")
# if("miceadds" %in% rownames(installed.packages()) == F) install.packages("miceadds")
if("stringr" %in% rownames(installed.packages()) == F) install.packages("stringr")

library(reshape)
#library(miceadds)
library(stringr)

prep.dat <- function(dat.s, dat.t, t){
  # Daten mergen
  
  if(is.null(dat.s)){
    if(is.null(dat.t)) 
      stop("Weder Schueler- noch Lehrerdaten der ersten Messung sind vorhanden")
    
    # Lehrerdaten
    if("Lehrperson" %in% names(dat.t)) dat.t$M_T <- dat.t$Lehrperson
    
    # Kollegendaten
    vs <- grep("^K",names(dat.t),value=T)
    if(length(vs) > 1){
      dat.t$M_K <- rowMeans(dat.t[,vs],na.rm=T)
      for(x in 1:5) 
        dat.t[,paste0("N",x,"_K")] <- rowSums(dat.t[,vs] == x,na.rm=T)
    } else if(length(vs)==1){
      dat.t$M_K <- dat.t[,vs]
      for(x in 1:4) 
        dat.t[,paste0("N",x,"_K")] <- 1*(dat.t[,vs] == x)
    }
    
    vv <- intersect(names(dat.t),c("MZP","Item.Nr","Bereich","Itemtext","M_T","M_K",paste0("N",1:4,"_K")))
    dat <- dat.t[,vv]
    
    
  } else if(is.null(dat.t)){
    if(is.null(dat.s)) stop("Weder Schueler- noch Lehrerdaten der ersten Messung sind vorhanden")
    
    vs <- grep("^S",names(dat.s),value=T)
    if(length(vs) > 1){
      dat.s$M_S <- rowMeans(dat.s[,vs],na.rm=T)
      for(x in 1:5) 
        dat.s[,paste0("N",x,"_S")] <- rowSums(dat.s[,vs] == x,na.rm=T)
    } else {
      dat.s$M_S <- dat.s[,vs]
      for(x in 1:5) 
        dat.s[,paste0("N",x,"_S")] <- 1*(dat.s[,vs] == x)
    }
    
    dat <- dat.s[,c("MZP","Item.Nr","Bereich","Itemtext","M_S",paste0("N",1:5,"_S"))]
    
  } else {
    
    # Schülerdaten
    
    vs <- grep("^S",names(dat.s),value=T)
    if(length(vs) > 1){
      dat.s$M_S <- rowMeans(dat.s[,vs],na.rm=T)
      for(x in 1:5) 
        dat.s[,paste0("N",x,"_S")] <- rowSums(dat.s[,vs] == x,na.rm=T)
    } else {
      dat.s$M_S <- dat.s[,vs]
      for(x in 1:5) 
        dat.s[,paste0("N",x,"_S")] <- 1*(dat.s[,vs] == x)
    }
    
    dat <- dat.s[,c("MZP","Item.Nr","Bereich","Itemtext","M_S",paste0("N",1:5,"_S"))]
    
    # Lehrerdaten
    if("Lehrperson" %in% names(dat.t)) dat.t$M_T <- dat.t$Lehrperson
    
    # Kollegendaten
    vs <- grep("^K",names(dat.t),value=T)
    if(length(vs) > 1){
      dat.t$M_K <- rowMeans(dat.t[,vs],na.rm=T)
      for(x in 1:5) 
        dat.t[,paste0("N",x,"_K")] <- rowSums(dat.t[,vs] == x,na.rm=T)
    } else if(length(vs)==1){
      dat.t$M_K <- dat.t[,vs]
      for(x in 1:4) 
        dat.t[,paste0("N",x,"_K")] <- 1*(dat.t[,vs] == x)
    }
    
    vv <- intersect(names(dat.t),c("MZP","Item.Nr","Bereich","M_T","M_K",paste0("N",1:4,"_K")))
    dat <- merge(dat,dat.t[,vv],all = T)
    
    vv <- grep("M_|^N",names(dat),value=T)
    if(length(vv) == 1) del <- which(is.na(dat[,vv]))
    if(length(vv) > 1) del <- which(rowMeans(is.na(dat[,vv])) == 1)
    if(length(del) > 0) dat <- dat[-del,]
    
    if(anyDuplicated(dat$Item.Nr)) 
      stop("Bitte prüfen Sie die Items und Bereichnamen in Schüler- und Lehrerdatenblatt ",
           t, "\nSie sind nicht identisch!",
           "\nAchten Sie bitte auch auf Leerzeichen und Punkt, Kommas, Sonderzeichen.")
    
    if(any(is.na(dat$Itemtext))){
      pp <- which(is.na(dat$Itemtext))
      dat$Itemtext[pp] <- dat.s$Itemtext[match(dat$Item.Nr[pp],dat.s$Item.Nr)]
    }
    
    if(any(is.na(dat$Itemtext))){
      pp <- which(is.na(dat$Itemtext))
      dat$Itemtext[pp] <- dat.t$Itemtext[match(dat$Item.Nr[pp],dat.t$Item.Nr)]
    }
    
  }
  
  return(list(dat, dat.s, dat.t))
  
}

print.emu <- function(dat,dat.s, dat.t,t,mb,PFAD){
  
  items0 <- dat$Item.Nr[which(dat$Bereich %in% mb)]
  
  # Erstmal ohne Item 26 (Students)
  items <- setdiff(items0,"I26s")
  
  mbb <- dat$Bereich[match(items,dat$Item.Nr)]
  lt.items <- sapply(mb, function(x) sum(mbb == x))
  m0b <- dat$Bereich[match(items0,dat$Item.Nr)]
  lt0.items <- sapply(mb, function(x) sum(m0b == x))
  
  itext <- dat$Itemtext[match(items,dat$Item.Nr)]
  if(any(is.na(itext))){
    pp <- which(is.na(itext))
    itext[pp] <- dat.t$Itemtext[match(items[pp],dat.t$Item.Nr)]
  }
  
  # Abbildung-Name
  pdf.name <- paste0("Abgleich_EMU-Skalen_",t,"__",time,".pdf")
  
  # Grafik speichern
  h <- floor(sum(lt.items)/2) + 3 * ("I26s"%in% items0)
  pdf(file.path(PFAD,pdf.name),onefile = T,width = 10,height = h)
  
  # Abbilden
  pp <- match(items, dat$Item.Nr)
  nc <- setdiff(unique(rowSums(dat[pp,grep("N(.)_K",names(dat))])),NA)
  ns <- setdiff(unique(rowSums(dat[pp,grep("N(.)_S",names(dat))])),NA)
  
  if(any(nc > 1) & any(ns > 1)){
    if(!("I26s"%in% items0))
      layout(mat = matrix(1:(lt*3),ncol=3,byrow=T),
             widths = c(3,1,1),
             heights = lt.items + 1)
    if("I26s" %in% items0)
      layout(mat = matrix(c(1:(lt*3),0,any(ns>1)*(lt*3+1),0),
                            ncol=3,byrow=T),
             widths = c(3,1,1),
             heights = c(lt.items + 1,3))
  } else if(any(nc > 1) & all(ns <= 1)){
    layout(mat = matrix(1:(lt*2),ncol=2,byrow=T),
           widths = c(3,1),
           heights = lt.items + 1)
  } else if(all(nc <= 1) & any(ns > 1)){
    if(!("I26s"%in% items0))
      layout(mat = matrix(1:(lt*2),ncol=2,byrow=T),
             widths = c(3,1),
             heights = lt.items + 1)
    if("I26s" %in% items0)
      layout(mat = matrix(c(1:(lt*2),0,lt*2+1),ncol=2,byrow=T),
             widths = c(3,1),
             heights = c(lt.items + 1,3))
  } else layout(mat = matrix(c(1:lt,rep(0,lt)),ncol=2),
                widths = c(3,1),heights = lt.items + 1)
  
  # Abgleich-Grafik
  for(b in mb){
    # b <- mb[5]
    
    items.b <- items[which(mbb == b)]
    text.b <- itext[match(items.b, items)]
    lt.b <- length(items.b)
    
    if(length(mb) == 1){
        cex.main <- cex <- cex.axis <- 0.6
        inset = c(0, -1/(lt.b+1))} else {
          cex.main <- cex <- cex.axis <- 0.8
          inset = c(0, -1/(lt.b+1))
        }
    
    # Mittelwert Grafik
    par(xpd=FALSE)
    par(mai = c(0.3,4,0.5,0.2))
    
    plot(x = rep(1:4,lt.b), 
         y = rep(lt.b:1,4), 
         ylim = c(0.5,lt.b+0.5),
         type="n",
         yaxt = "n",xaxt = "n",
         xlab = "",ylab="",cex = 0.5)
    
    axis(side = 3,at = seq(1,4,0.5),cex.axis = cex.axis,
         labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
    par(xpd=T)
    mtext(text = paste(b,t),side = 2,line = 2,at = ceiling(lt.b+1),
          font = 2,
          cex = cex,las=1)
    
    # Items
    par(xpd=FALSE)
    text.b <- gsub(" $","",text.b)
    text.b1 <- strsplit(text.b,split = " ")
    text <- NULL
    for(i in 1:length(text.b1)){
      string <- text.b1[[i]]
      string <- str_c(string, collapse = " ")
      string <- gsub(" $","",string)
      string <- gsub("\\.$","",string)
      # max length of string <- 60
      num.chars <- nchar(string)
      if(num.chars > 60){
        # find last space before 60
        pp <- strsplit(substr(string,1,60),split = " ")[[1]]
        first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
        last <- gsub(first,"",string)
        last <- gsub("^ ","",last)
        string <- paste0(first,"\n",last)
      }
      text[i] <- string
    }
    
    if(length(mb) == 1) cex.item = 0.6 else cex.item = 1
    axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
         cex.axis = cex.item)
    abline(v = seq(1,4,0.5),col="lightgrey")
    abline(h = c(1:lt.b),col="lightgrey",lty=2)
    if("M_S" %in% names(dat))
      points(x = dat$M_S[match(items.b,dat$Item.Nr)],
             y = lt.b:1,type="b",col="orange",pch = 15,cex = 1.2)
    if("M_T" %in% names(dat))
      points(x = dat$M_T[match(items.b,dat$Item.Nr)],
             y = lt.b:1,type="b",col="green",pch = 19,cex = 1.1)
    if("M_K" %in% names(dat))
      points(x = dat$M_K[match(items.b,dat$Item.Nr)],
             y = lt.b:1,type="b",col="purple",pch = 18, cex = 0.9)
    par(xpd=TRUE)
    legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = cex,xjust = 0.5,
           legend = c("Schüler","Lehrperson","Kollegen"),
           pch=c(15,19,18),lty=2,col=c("orange","green","purple"))
    
    # Verteilung Schülerantworte ohne I26s
    if(any(ns > 1)){
      par(xpd=FALSE)
      par(mai = c(0.3,0.5,0.5,0.2))
      
      mat1 <- dat[match(items.b[lt.b:1],dat$Item.Nr),
                   c("Item.Nr",paste0("N",1:4,"_S"))]
      colnames(mat1)[-1] <- paste0("N",1:4)
      
      bp1 <- barplot(t(as.matrix(mat1[,-1])),beside = F,horiz=T,
                     xaxt="n",yaxt="n",
                     legend.text = T,
                     border=F,col=c("yellow","orange","darkorange","orange3"),
                     args.legend = list(x = "bottom", bty = "n", 
                                        inset=inset,
                                        horiz=T,
                                        cex = cex),
                     main = "Verteilung der Schülerantworte",cex.main=cex.main)
      
      y <- lab <- (as.matrix(mat1[,-1]))
      for(ii in 2:4) y[,ii] <- rowSums(y[,c(ii,ii-1)])
      y <- y - lab/2
      lab[lab == 0] <- NA
      text(y,bp1, labels=as.character(lab), cex=0.62)
      
      # Mittelwert:
      M <- round(dat$M_S[match(items.b,dat$Item.Nr)],1)[lt.b:1]
      lab.M <- paste0("M = ",M)
      lab.M[lab.M == "M = NA"] <- ""
      axis(side = 2,at = seq(0.7,lt.b+0.1*lt.b,length.out = lt.b),
           labels = lab.M,cex.axis=cex.axis,
           tick = F,pos = 0,las=1)
    }

    
    # Verteilung Kollegenantworte
    if(any(nc > 1)){
      par(xpd=FALSE)
      par(mai = c(0.3,0.5,0.5,0.2))
      mat1 <- dat[match(items.b[lt.b:1],dat$Item.Nr),
                   c("Item.Nr",paste0("N",1:4,"_K"))]
      colnames(mat1)[-1] <- paste0("N",1:4)
      bp2 <- barplot(t(as.matrix(mat1[,-1])),beside = F,horiz=T,
                     xaxt="n",yaxt="n",
                     legend.text = T,border=F,col=c("lightpink","pink3","purple1","purple3"),
                     args.legend = list(x = "bottom", bty = "n", 
                                        inset=inset,
                                        horiz=T,
                                        cex = cex),
                     main = "Verteilung der Kollegenantworte",cex.main=0.8)
      y <- lab <- (as.matrix(mat1[,-1]))
      for(ii in 2:4) y[,ii] <- rowSums(y[,c(ii,ii-1)])
      y <- y - lab/2
      lab[lab == 0] <- NA
      text(y,bp2, labels=as.character(lab), cex=0.62)
      
      # Mittelwert
      M <- round(dat$M_K[match(items.b,dat$Item.Nr)],1)[lt.b:1]
      lab.M <- paste0("M = ",M)
      lab.M[lab.M == "M = NA"] <- ""
      axis(side = 2,at = seq(0.7,lt.b+0.1*lt.b,length.out = lt.b),
           labels = lab.M,cex.axis=cex.axis,
           tick = F,pos = 0,las=1)
    }
    
  }
  
  # Abbildung Item I26s
  if("I26s" %in% items0){
    par(mai = c(0.5,0,0.5,0.2))
    mat1 <- dat[match("I26s",dat$Item.Nr),
                c("Item.Nr",paste0("N",1:5,"_S"))]
    colnames(mat1)[-1] <- paste0("N",1:5)
    
    M <- round(dat$M_S[match("I26s",dat$Item.Nr)],1)
    lab.M <- paste0("M = ",M)
    
    bp1 <- barplot(t(as.matrix(mat1[,-1])),beside = T,horiz=F,space = 0.2,
                   xaxt="n",yaxt="n",
                   legend.text = T,
                   border=F,
                   col=c("yellow","orange","darkorange","orange3","brown"),
                   args.legend = list(x = "top", bty = "n", 
                                      inset=c(0, -0.5),horiz=T,
                                      cex = cex),
                   main = paste0("Der Stoff dieser Unterrichtsstunde\nwar für mich…",
                                 " (",t,", ",lab.M,")"),
                   cex.main=cex.main)
    axis(side = 1,at = seq(0.7,5.7,length.out=5),tick = F,
         labels = c("zu\nleicht","etwas zu\nleicht","genau\nrichtig",
                    "etwas zu\nschwierig","zu\nschwierig"),cex.axis = cex.axis,
         las = 3)
    lab <- (as.matrix(mat1[,-1]))
    # lab[lab == 0] <- NA
    y <- as.vector(mat1[,-1])
    y[y == 0] <- 1
    text(x=seq(0.7,5.7,length.out=5),y = y,
         bp1, labels=as.character(lab), cex=0.62)
    
  }
  
  dev.off()
  
}

print.zusatz <- function(dat, dat.s, dat.t, t,zb,PFAD){
  
  # Wenn eine  Skala mehr als 40 Items hat, dann trenne es in 3
  # Wenn eine Skala mehr als 20 Items hat, dann trenne es in 2
  # wenn mehrere Skalen weniger als 20 Items hat, 
  # dann Erg. von mehreren Skalen werden in einer Seite gedruckt
  # layout wird variabel erstellt.
  
  # Abbildung-Name
  pdf.name <- paste0("Abgleich_Zusatzbereich_",t,"__",time,".pdf")
  
  items <- dat$Item.Nr[which(dat$Bereich %in% zb)]
  mbb <- dat$Bereich[match(items,dat$Item.Nr)]
  lt.items <- sapply(zb, function(x) sum(mbb == x))
  
  # Neu verteilen anhand Itemuzahl pro Skala
  nitems <- list()
  # Anzahl Skalen mit Itemzahl >= x
  n41 <- sum(lt.items >= 41)
  if(n41 > 0){
    s41 <- names(lt.items)[lt.items >= 41]
    # in 3 teilen
    for(ss in s41){
      s.items <- dat$Item.Nr[which(dat$Bereich == ss)]
      trenn <- floor(length(s.items)/3)
      nitems[[paste0(ss," (Seite 1)")]] <- s.items[1:trenn]
      nitems[[paste0(ss," (Seite 2)")]] <- s.items[(trenn+1):(trenn*2)]
      nitems[[paste0(ss," (Seite 3)")]] <- s.items[(trenn*2+1):length(s.items)]
    }
  }
  n21 <- sum(lt.items >= 21 & lt.items <= 40)
  if(n21 > 0){
    s21 <- names(lt.items)[lt.items >= 21 & lt.items <= 40]
    # in 2 teilen
    for(ss in s21){
      # ss = s21[1]
      s.items <- dat$Item.Nr[which(dat$Bereich == ss)]
      trenn <- floor(length(s.items)/2)
      nitems[[paste0(ss," (Seite 1)")]] <- s.items[1:trenn]
      nitems[[paste0(ss," (Seite 2)")]] <- s.items[(trenn+1):length(s.items)]
    }
  }
  n20 <- sum(lt.items <= 20)
  if(n20 > 0){
    # if Itemzahl insgesamt < 30: alle in einer Seite
    # if Itemzahl insgesamt >= 30: alle in 2 Seiten
    s20 <- names(lt.items)[lt.items <= 20]
    if(sum(lt.items[s20] < 30)){
      s.items <- dat$Item.Nr[which(dat$Bereich %in% s20)]
      nitems[["Rest"]] <- s.items
    } else {
      lt.s20 <- lt.items[s20]
      X <- lt.s20 <- lt.s20[order(lt.s20,decreasing = T)]
      for(ll in 2:length(lt.s20)) X[ll] <- X[ll] + X[ll-1]
      trenn <- ceiling(sum(lt.items[s20])/2)
      pp <- 1*(X <= trenn)
      
      # Gruppe 1
      ss <- names(pp)[pp == 1]
      s.items <- dat$Item.Nr[which(dat$Bereich %in% ss)]
      nitems[["Gruppe 1"]] <- s.items
      
      # Gruppe 2
      ss <- names(pp)[pp == 0]
      s.items <- dat$Item.Nr[which(dat$Bereich %in% ss)]
      nitems[["Gruppe 2"]] <- s.items
    }
  }
  
  fu <- sapply(1:length(nitems),function(x) nitems[[x]][1])
  nitems <- nitems[order(fu)]
  
  # Sind alle Skalen und Items enthalten?
  if(!all(items %in% unlist(nitems))) stop("es fehlen Zusatzitems")
  
  # Grafik speichern
  lt.n <- sapply(1:length(nitems),function(x) length(nitems[[x]]))
  h = ceiling(max(lt.n) / 3) + 1
  
  pdf(file.path(PFAD,pdf.name),onefile = T,width=10, 
      height = h)
  
  # Pro Objekt in nitems eine Seite ausdrucken
  
  for(jj in 1:length(nitems)){
    # jj <- 4
    # Items
    items.jj <- nitems[[jj]]
    
    # Itemformulierung
    itext <- dat$Itemtext[match(items.jj,dat$Item.Nr)]
    if(any(is.na(itext))){
      pp <- which(is.na(itext))
      itext[pp] <- dat.t$Itemtext[match(items.jj[pp],dat.t$Item.Nr)]
    }
    if(any(is.na(itext))){
      pp <- which(is.na(itext))
      itext[pp] <- dat.t$Itemtext[match(items.jj[pp],dat.s$Item.Nr)]
    }
    
    # Skalen
    sk.jj <- dat$Bereich[match(items.jj,dat$Item.Nr)]
    lt.jj <- length(unique(sk.jj))
    
    # nur eine Skala
    if(lt.jj == 1){
      # Abbilden
      pp <- match(items.jj, dat$Item.Nr)
      nc <- setdiff(unique(rowSums(dat[pp,grep("N(.)_K",names(dat))])),NA)
      ns <- setdiff(unique(rowSums(dat[pp,grep("N(.)_S",names(dat))])),NA)
      
      # Eine Seite, Eine Skala
      if(any(nc > 1) & any(ns > 1)){
        layout(mat = matrix(1:3,ncol=3,byrow=T),
               widths = c(3,1,1),heights = length(items.jj) + 1, respect = F)
      } else if(all(nc <= 1) & any(ns > 1) | any(nc > 1) & all(ns <= 1)){
        layout(mat = matrix(1:2,ncol=2,byrow=T),
               widths = c(3,1),heights = length(items.jj) + 1, respect = F)
      } else layout(mat = matrix(c(1,0),ncol=2),
                    widths = c(3,1),heights = length(items.jj) + 1, respect = F)
      
      # Abgleich-Grafik
      
      b <- unique(sk.jj)
      items.b <- items.jj
      text.b <- itext[match(items.b, items.jj)]
      lt.b <- length(items.b)
      
      if(lt.b < 7){
        cex.main <- cex <- cex.axis <- 0.6
        inset = c(0, -(1/(lt.b+1)))
        
        cex.item = 0.7
        inset = c(0, -0.1)} else {
          cex.main <- cex <- cex.axis <- 0.8
          inset <- c(0, -(1/lt.b+1))
          cex.item = 0.9
        }
      
      # Mittelwert Grafik
      par(xpd=FALSE)
      par(mai = c(0.7,4,0.7,0.5))
      
      plot(x = rep(1:4,lt.b), 
           y = rep(lt.b:1,4), 
           ylim = c(0.5,lt.b+0.5),
           type="n",
           yaxt = "n",xaxt = "n",
           xlab = "",ylab="",cex = 0.5)
      axis(side = 3,at = seq(1,4,0.5),cex.axis = cex.axis,
           labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
      par(xpd=T)
      mtext(text = paste(b,t),side = 2,line = 2,at = ceiling(lt.b+1),
            font = 2,
            cex = cex,las=1)
      
      # Items
      par(xpd=FALSE)
      text.b <- gsub(" $","",text.b)
      text.b1 <- strsplit(text.b,split = " ")
      text <- NULL
      for(i in 1:length(text.b1)){
        string <- text.b1[[i]]
        string <- str_c(string, collapse = " ")
        string <- gsub(" $","",string)
        string <- gsub("\\.$","",string)
        # max length of string <- 60
        num.chars <- nchar(string)
        if(num.chars > 60){
          # find last space before 60
          pp <- strsplit(substr(string,1,60),split = " ")[[1]]
          first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
          last <- gsub(first,"",string)
          last <- gsub("^ ","",last)
          string <- paste0(first,"\n",last)
        }
        text[i] <- string
      }
      
      axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
           cex.axis = cex.item)
      abline(v = seq(1,4,0.5),col="lightgrey")
      abline(h = c(1:lt.b),col="lightgrey",lty=2)
      if("M_S" %in% names(dat))
        points(x = dat$M_S[match(items.b,dat$Item.Nr)],
               y = lt.b:1,type="b",col="orange",pch = 15,cex = 1.2)
      if("M_T" %in% names(dat))
        points(x = dat$M_T[match(items.b,dat$Item.Nr)],
               y = lt.b:1,type="b",col="green",pch = 19,cex = 1.1)
      if("M_K" %in% names(dat))
        points(x = dat$M_K[match(items.b,dat$Item.Nr)],
               y = lt.b:1,type="b",col="purple",pch = 18, cex = 0.9)
      par(xpd=TRUE)
      if(lt.b < 7) y = 0.1 else y = -0.2
      legend(x=2.5,y = y,bty = "n" ,horiz=T,cex = cex,xjust = 0.5,
             legend = c("Schüler","Lehrperson","Kollegen"),
             pch=c(15,19,18),lty=2,col=c("orange","green","purple"))
      
      # Verteilung Schülerantworte
      if(any(ns > 1)){
        par(xpd=FALSE)
        par(mai = c(0.7,0.5,0.7,0.5))
        
        mat1 <- dat[match(items.b[lt.b:1],dat$Item.Nr),
                     c("Item.Nr",paste0("N",1:4,"_S"))]
        colnames(mat1)[-1] <- paste0("N",1:4)
        bp1 <- barplot(t(as.matrix(mat1[,-1])),beside = F,horiz=T,
                       xaxt="n",yaxt="n",
                       legend.text = T,
                       border=F,col=c("yellow","orange","darkorange","orange3"),
                       args.legend = list(x = "bottom", bty = "n", 
                                          inset=inset,
                                          horiz=T,
                                          cex = cex-0.1),
                       main = "Verteilung der Schülerantworte",cex.main=cex.main)
        
        y <- lab <- (as.matrix(mat1[,-1]))
        for(ii in 2:4) y[,ii] <- rowSums(y[,c(ii,ii-1)])
        y <- y - lab/2
        lab[lab == 0] <- NA
        text(y,bp1, labels=as.character(lab), cex=0.62)
        
        # Mittelwert:
        M <- round(dat$M_S[match(items.b,dat$Item.Nr)],1)[lt.b:1]
        lab.M <- paste0("M = ",M)
        lab.M[lab.M == "M = NA"] <- ""
        axis(side = 2,at = seq(0.7,lt.b+0.2*(lt.b-2),length.out = lt.b),
             labels = lab.M,cex.axis=cex.axis,
             tick = F,pos = 0,las=1)
      }
      
      # Verteilung Kollegenantworte
      if(any(nc > 1)){
        par(xpd=FALSE)
        par(mai = c(0.7,0.5,0.7,0.5))
        mat1 <- dat[match(items.b[lt.b:1],dat$Item.Nr),
                     c("Item.Nr",paste0("N",1:4,"_K"))]
        colnames(mat1)[-1] <- paste0("N",1:4)
        bp2 <- barplot(t(as.matrix(mat1[,-1])),beside = F,horiz=T,
                       xaxt="n",yaxt="n",
                       legend.text = T,border=F,col=c("lightpink","pink3","purple1","purple3"),
                       args.legend = list(x = "bottom", bty = "n", 
                                          inset=inset,
                                          horiz=T,
                                          cex = cex-.1),
                       main = "Verteilung der Kollegenantworte",cex.main=cex.main)
        y <- lab <- (as.matrix(mat1[,-1]))
        for(ii in 2:4) y[,ii] <- rowSums(y[,c(ii,ii-1)])
        y <- y - lab/2
        lab[lab == 0] <- NA
        text(y,bp2, labels=as.character(lab), cex=0.62)
        
        # Mittelwert
        M <- round(dat$M_K[match(items.b,dat$Item.Nr)],1)[lt.b:1]
        lab.M <- paste0("M = ",M)
        lab.M[lab.M == "M = NA"] <- ""
        axis(side = 2,at = seq(0.7,lt.b+0.2*(lt.b-2),length.out = lt.b),
             labels = lab.M,cex.axis=cex.axis,
             tick = F,pos = 0,las=1)
      }
      
      
    }
    
    # Mehrere Skalen
    if(lt.jj > 1){
      # Abbilden
      pp <- match(items.jj, dat$Item.Nr)
      nc <- setdiff(unique(rowSums(dat[pp,grep("N(.)_K",names(dat))])),NA)
      ns <- setdiff(unique(rowSums(dat[pp,grep("N(.)_S",names(dat))])),NA)
      
      # Anzahl Items
      jb <- unique(sk.jj)
      lt.jb <- sapply(jb, function(x) sum(sk.jj == x))
      
      # Eine Seite, Mehrere Skala
      if(any(nc > 1) & any(ns > 1)){
        layout(mat = matrix(1:(lt.jj*3),ncol=3,byrow=T),
               widths = c(3,1,1),heights = lt.jb + 1)
      } else if(all(nc <= 1) & any(ns > 1) | any(nc > 1) & all(ns <= 1)){
        layout(mat = matrix(1:(lt.jj*2),ncol=2,byrow=T),
               widths = c(3,1),heights = lt.jb + 1)
      } else layout(mat = matrix(c(1,lt.jj,rep(0,lt.jj)),ncol=2),
                    widths = c(3,1),heights = lt.jb + 1)
      
      # Abgleich-Grafik
      for(b in jb){
        # b <- jb[1]
        items.b <- items.jj[sk.jj == b]
        text.b <- itext[match(items.b, items.jj)]
        lt.b <- length(items.b)
        
        if(lt.b < 7){
          cex.main <- cex <- cex.axis <- 0.6
          inset = c(0, -(1/(lt.b+1)))
          
          cex.item = 0.7
          inset = c(0, -0.1)} else {
            cex.main <- cex <- cex.axis <- 0.8
            inset <- c(0, -(1/lt.b+1))
            cex.item = 0.9
          }
        
        # Mittelwert Grafik
        par(xpd=FALSE)
        par(mai = c(0.5,4,0.7,0.5))
        
        plot(x = rep(1:4,lt.b), 
             y = rep(lt.b:1,4), 
             ylim = c(0.5,lt.b+0.5),
             type="n",
             yaxt = "n",xaxt = "n",
             xlab = "",ylab="",cex = 0.5)
        axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
             labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
        par(xpd=T)
        mtext(text = paste(b,t),side = 2,line = 2,at = ceiling(lt.b+1),
              font = 2,
              cex = 0.7,las=1)
        
        # Items
        par(xpd=FALSE)
        text.b <- gsub(" $","",text.b)
        text.b1 <- strsplit(text.b,split = " ")
        text <- NULL
        for(i in 1:length(text.b1)){
          string <- text.b1[[i]]
          string <- str_c(string, collapse = " ")
          string <- gsub(" $","",string)
          string <- gsub("\\.$","",string)
          # max length of string <- 60
          num.chars <- nchar(string)
          if(num.chars > 60){
            # find last space before 60
            pp <- strsplit(substr(string,1,60),split = " ")[[1]]
            first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
            last <- gsub(first,"",string)
            last <- gsub("^ ","",last)
            string <- paste0(first,"\n",last)
          }
          text[i] <- string
        }
        
        axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
             cex.axis = 1)
        abline(v = seq(1,4,0.5),col="lightgrey")
        abline(h = c(1:lt.b),col="lightgrey",lty=2)
        if("M_S" %in% names(dat))
          points(x = dat$M_S[match(items.b,dat$Item.Nr)],
                 y = lt.b:1,type="b",col="orange",pch = 15,cex = 1.2)
        if("M_T" %in% names(dat))
          points(x = dat$M_T[match(items.b,dat$Item.Nr)],
                 y = lt.b:1,type="b",col="green",pch = 19,cex = 1.1)
        if("M_K" %in% names(dat))
          points(x = dat$M_K[match(items.b,dat$Item.Nr)],
                 y = lt.b:1,type="b",col="purple",pch = 18, cex = 0.9)
        par(xpd=TRUE)
        legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
               legend = c("Schüler","Lehrperson","Kollegen"),
               pch=c(15,19,18),lty=2,col=c("orange","green","purple"))
        
        # Verteilung Schülerantworte
        if(any(ns > 1)){
          par(xpd=FALSE)
          par(mai = c(0.5,0.5,0.7,0.5))
          
          mat1 <- dat[match(items.b[lt.b:1],dat$Item.Nr),
                       c("Item.Nr",paste0("N",1:4,"_S"))]
          colnames(mat1)[-1] <- paste0("N",1:4)
          bp1 <- barplot(t(as.matrix(mat1[,-1])),beside = F,horiz=T,
                         xaxt="n",yaxt="n",
                         legend.text = T,
                         border=F,col=c("yellow","orange","darkorange","orange3"),
                         args.legend = list(x = "bottom", bty = "n", 
                                            #inset=c(0, -(0.2/lt.b)),
                                            horiz=T,
                                            cex = 0.7),
                         main = "Verteilung der Schülerantworte",cex.main=0.8)
          
          y <- lab <- (as.matrix(mat1[,-1]))
          for(ii in 2:4) y[,ii] <- rowSums(y[,c(ii,ii-1)])
          y <- y - lab/2
          lab[lab == 0] <- NA
          text(y,bp1, labels=as.character(lab), cex=0.62)
          
          # Mittelwert:
          M <- round(dat$M_S[match(items.b,dat$Item.Nr)],1)[lt.b:1]
          lab.M <- paste0("M = ",M)
          lab.M[lab.M == "M = NA"] <- ""
          axis(side = 2,at = seq(0.7,lt.b+0.2*(lt.b-2),length.out = lt.b),
               labels = lab.M,cex.axis=0.8,
               tick = F,pos = 0,las=1)
        }
        
        # Verteilung Kollegenantworte
        if(any(nc > 1)){
          par(xpd=FALSE)
          par(mai = c(0.5,0.5,0.7,0.5))
          mat1 <- dat[match(items.b[lt.b:1],dat$Item.Nr),
                       c("Item.Nr",paste0("N",1:4,"_K"))]
          colnames(mat1)[-1] <- paste0("N",1:4)
          bp2 <- barplot(t(as.matrix(mat1[,-1])),beside = F,horiz=T,
                         xaxt="n",yaxt="n",
                         legend.text = T,border=F,col=c("lightpink","pink3","purple1","purple3"),
                         args.legend = list(x = "bottom", bty = "n", 
                                            #inset=c(0, -(0.2/lt.b)),
                                            horiz=T,
                                            cex = 0.7),
                         main = "Verteilung der Kollegenantworte",cex.main=0.8)
          y <- lab <- (as.matrix(mat1[,-1]))
          for(ii in 2:4) y[,ii] <- rowSums(y[,c(ii,ii-1)])
          y <- y - lab/2
          lab[lab == 0] <- NA
          text(y,bp2, labels=as.character(lab), cex=0.62)
          
          # Mittelwert
          M <- round(dat$M_K[match(items.b,dat$Item.Nr)],1)[lt.b:1]
          lab.M <- paste0("M = ",M)
          lab.M[lab.M == "M = NA"] <- ""
          axis(side = 2,at = seq(0.7,lt.b+0.2*(lt.b-2),length.out = lt.b),
               labels = lab.M,cex.axis=0.8,
               tick = F,pos = 0,las=1)
        }
      }
      
      
      
    }
    
  }
  
  dev.off()
  
  
}

bereich <- c("KLASSENMANAGEMENT",
             "LERNFÖRDERLICHES KLIMA UND MOTIVIERUNG",
             "KLARHEIT UND STRUKTURIERUNG",
             "AKTIVIERUNG UND FÖRDERUNG",
             "BILANZ")

# time <- Sys.time()
# time <- gsub(" ","_",time)
# time <- gsub(":","",time)
time <- Sys.Date()

# Daten einlesen

{
  # Schülerdaten
  lf <- list.files(PFAD,"Dateneingabe_Schueler(.)*.csv",full.names=T)
  if(length(lf) == 0) warning("Achtung: Keine Schuelerdaten (.csv) gefunden")
  
  dat.s1 <- dat.s2 <- NULL
  
  # T1
  if(length(grep("T1",lf))>0){
    pp <- grep("T1",lf)
    lf1 <- max(lf[pp])
    dat.s1 <- read.csv2(lf1,encoding = "utf8")
    dat.s1$Bereich <- toupper(dat.s1$Bereich)
    
    # alle leere Spalten löschen
    if(any(colMeans(is.na(dat.s1)) == 1)){
      del <- which(colMeans(is.na(dat.s1)) == 1)
      if(length(del)>0) dat.s1 <- dat.s1[,-del]
      vs <- grep("^S",names(dat.s1),value=T)
      if(length(vs) == 0) dat.s1 <- NULL
    }
    
    # alle leere Zeilen löschen
    cn <- grep("^S",colnames(dat.s1),value=T)
    if(length(cn)==1){
      del <- which(is.na(dat.s1[,cn]))
      if(length(del)>0) dat.s1 <- dat.s1[-del,]
      nn <- nrow(dat.s1)
      if(nn == 0) dat.s1 <- NULL
    } else if(any(rowMeans(is.na(dat.s1[,cn])) == 1)){
      del <- which(rowMeans(is.na(dat.s1[,cn])) == 1)
      if(length(del)>0) dat.s1 <- dat.s1[-del,]
      nn <- nrow(dat.s1)
      if(nn == 0) dat.s1 <- NULL
    }
    
    # Check Werte
    vs <- grep("^S",names(dat.s1),value=T)
    items <- dat.s1$Item.Nr
    if("I26s" %in% items){
      if(!all(as.numeric(names(table(unlist(dat.s1[-match("I26s",dat.s1$Item.Nr),vs])))) %in% c(1:4)))
        stop("Schülerdaten T1: Es gibt ungültige Werte (1 bis 4)")
      if(!all(as.numeric(names(table(unlist(dat.s1[match("I26s",dat.s1$Item.Nr),vs])))) %in% c(1:5)))
        stop("Schülerdaten T1, Item 26s: Es gibt ungültige Werte (1 bis 5)")
    } else {
      if(!all(as.numeric(names(table(unlist(dat.s1[,vs])))) %in% c(1:4)))
        stop("Schülerdaten T1: Es gibt ungültige Werte (1 bis 4)")
    }
    
    
  }
  
  # T2
  if(length(grep("T2",lf))>0){
    pp <- grep("T2",lf)
    lf2 <- max(lf[pp])
    dat.s2 <- read.csv2(lf2,encoding = "utf8")
    dat.s2$Bereich <- toupper(dat.s2$Bereich)
    
    # alle leere Spalten löschen
    if(any(colMeans(is.na(dat.s2)) == 1)){
      del <- which(colMeans(is.na(dat.s2)) == 1)
      if(length(del)>0) dat.s2 <- dat.s2[,-del]
      vs <- grep("^S",names(dat.s2),value=T)
      if(length(vs) == 0) dat.s2 <- NULL
    }
    # alle leere Zeilen löschen
    cn <- grep("^S",colnames(dat.s2),value=T)
    if(length(cn)==1){
      del <- which(is.na(dat.s2[,cn]))
      if(length(del)>0) dat.s2 <- dat.s2[-del,]
      nn <- nrow(dat.s2)
      if(nn == 0) dat.s2 <- NULL
    } else if(any(rowMeans(is.na(dat.s2[,cn])) == 1)){
      del <- which(rowMeans(is.na(dat.s2[,cn])) == 1)
      if(length(del)>0) dat.s2 <- dat.s2[-del,]
      nn <- nrow(dat.s2)
      if(nn == 0) dat.s2 <- NULL
    }
    
    # Check Werte
    vs <- grep("^S",names(dat.s2),value=T)
    items <- dat.s2$Item.Nr
    if("I26s" %in% items){
      if(!all(as.numeric(names(table(unlist(dat.s2[-match("I26s",dat.s2$Item.Nr),vs])))) %in% c(1:4)))
        stop("Schülerdaten T2: Es gibt ungültige Werte (1 bis 4)")
      if(!all(as.numeric(names(table(unlist(dat.s2[match("I26s",dat.s2$Item.Nr),vs])))) %in% c(1:5)))
        stop("Schülerdaten T2, Item 26s: Es gibt ungültige Werte (1 bis 5)")
    } else {
      if(!all(as.numeric(names(table(unlist(dat.s2[,vs])))) %in% c(1:4)))
        stop("Schülerdaten T2: Es gibt ungültige Werte (1 bis 4)")
    }
  }
  
  # Lehrerdaten
  lf <- list.files(PFAD,"Dateneingabe_Lehrer(.)*.csv",full.names = T)
  if(length(lf) == 0) warning("Achtung: Keine Lehrerdaten (.csv) zum Abgleich gefunden")
  
  dat.t1 <- dat.t2 <- NULL
  
  # T1
  if(length(grep("T1",lf))>0){
    pp <- grep("T1",lf)
    lf1 <- max(lf[pp])
    dat.t1 <- read.csv2(lf1,encoding = "utf8")
    dat.t1$Bereich <- toupper(dat.t1$Bereich)
    
    # alle leere Spalten löschen
    if(any(colMeans(is.na(dat.t1)) == 1)){
      del <- which(colMeans(is.na(dat.t1)) == 1)
      if(length(del)>0) dat.t1 <- dat.t1[,-del]
      ks <- grep("^Lehrperson|^K",names(dat.t1),value=T)
      if(length(ks) == 0) dat.t1 <- NULL
    }
    # alle leere Zeilen löschen
    cn <- grep("^Lehrperson|^K",colnames(dat.t1),value=T)
    if(length(cn)==1){
      del <- which(is.na(dat.t1[,cn]))
      if(length(del)>0) dat.t1 <- dat.t1[-del,]
      nn <- nrow(dat.t1)
      if(nn == 0) dat.t1 <- NULL
    } else if(any(rowMeans(is.na(dat.t1[,cn])) == 1)){
      del <- which(rowMeans(is.na(dat.t1[,cn])) == 1)
      if(length(del)>0) dat.t1 <- dat.t1[-del,]
      nn <- nrow(dat.t1)
      if(nn == 0) dat.t1 <- NULL
    }
    
    # Check Werte
    vs <- grep("^Lehrperson|^K",names(dat.t1),value=T)
    items <- dat.t1$Item.Nr
    if(!all(as.numeric(names(table(unlist(dat.t1[,vs])))) %in% c(1:4)))
      stop("Lehrerdaten T1: Es gibt ungültige Werte (1 bis 4)")
  }
  
  # T2
  if(length(grep("T2",lf))>0){
    pp <- grep("T2",lf)
    lf2 <- max(lf[pp])
    dat.t2 <- read.csv2(lf2,encoding = "utf8")
    dat.t2$Bereich <- toupper(dat.t2$Bereich)
    
    # alle leere Spalten löschen
    if(any(colMeans(is.na(dat.t2)) == 1)){
      del <- which(colMeans(is.na(dat.t2)) == 1)
      if(length(del)>0) dat.t2 <- dat.t2[,-del]
      ks <- grep("^Lehrperson|^K",names(dat.t2),value=T)
      if(length(ks) == 0) dat.t2 <- NULL
    }
    # alle leere Zeilen löschen
    cn <- grep("^Lehrperson|^K",colnames(dat.t2),value=T)
    if(length(cn)==1){
      del <- which(is.na(dat.t2[,cn]))
      if(length(del)>0) dat.t2 <- dat.t2[-del,]
      nn <- nrow(dat.t2)
      if(nn == 0) dat.t2 <- NULL
    } else if(any(rowMeans(is.na(dat.t2[,cn])) == 1)){
      del <- which(rowMeans(is.na(dat.t2[,cn])) == 1)
      if(length(del)>0) dat.t2 <- dat.t2[-del,]
      nn <- nrow(dat.t2)
      if(nn == 0) dat.t2 <- NULL
    }
    
    # Check Werte
    vs <- grep("^Lehrperson|^K",names(dat.t2),value=T)
    items <- dat.t2$Item.Nr
    if(!all(as.numeric(names(table(unlist(dat.t2[,vs])))) %in% c(1:4)))
      stop("Lehrerdaten T2: Es gibt ungültige Werte (1 bis 4)")
  }
  
}

#-----------------------------------------------------------------------------##
# Ergebnisse T1

if(print.T1 == 1){
  
  # Daten mergen
  dat.list <- prep.dat(dat.s = dat.s1, dat.t = dat.t1,t = "T1")
  dat1 <- dat.list[[1]]
  dat.s1 <- dat.list[[2]]
  dat.t1 <- dat.list[[3]]
  
  # Abbildungen
  
  {
    
    dat1$lnr <- gsub("I|L|s","",dat1$Item.Nr)
    dat1$lnr <- gsub("Z","20",dat1$lnr)
    dat1$lnr <- as.numeric(dat1$lnr)
    dat1 <- dat1[order(dat1$lnr),]
    
    # EMU-Items
    items <- dat1$Item.Nr
    e.items <- grep("^I",items,value=T)
    z.items <- grep("^ZI",items,value=T)
    
    # Bereiche
    bb <- unique(dat1$Bereich)
    mb <- intersect(bb,bereich)
    zb <- setdiff(bb,bereich)
    
    
    #--------------------------------------------------------
    # T1 - EMU Abbildungen
    
    lt <- length(mb)
    
    if(lt > 0){
      print.emu(dat = dat1,dat.s = dat.s1,dat.t = dat.t1,t = "T1",mb = mb,PFAD = PFAD)
    }
    
    
    #--------------------------------------------------------
    # T1 - Zusatzskalen
    
    lt <- length(zb)
    
    if(lt > 0){
      print.zusatz(dat = dat1, dat.s = dat.s1, dat.t = dat.t1, 
                   t = "T1",zb = zb, PFAD = PFAD)
    }
    
    
  }
  
  print("Ergebnisse T1 wurden ausgedruckt und gespeichert")

}

#-----------------------------------------------------------------------------##
# Ergebnisse T2

if(print.T2 == 1){
  
  # Daten mergen
  dat.list <- prep.dat(dat.s = dat.s2, dat.t = dat.t2,t = "T2")
  dat2 <- dat.list[[1]]
  dat.s2 <- dat.list[[2]]
  dat.t2 <- dat.list[[3]]
  
  # Abbildungen
  
  {
    
    dat2$lnr <- gsub("I|L|s","",dat2$Item.Nr)
    dat2$lnr <- gsub("Z","20",dat2$lnr)
    dat2$lnr <- as.numeric(dat2$lnr)
    dat2 <- dat2[order(dat2$lnr),]
    
    # EMU-Items
    items <- dat2$Item.Nr
    e.items <- grep("^I",items,value=T)
    z.items <- grep("^ZI",items,value=T)
    
    # Bereiche
    bb <- unique(dat2$Bereich)
    mb <- intersect(bb,bereich)
    zb <- setdiff(bb,bereich)
    
    
    #--------------------------------------------------------
    # T2 - EMU Abbildungen
    
    lt <- length(mb)
    
    if(lt > 0){
      print.emu(dat = dat2,dat.s = dat.s2,dat.t = dat.t2,
                t = "T2",mb = mb,PFAD = PFAD)
    }
    
    
    #--------------------------------------------------------
    # T2 - Zusatzskalen
    
    lt <- length(zb)
    
    if(lt > 0){
      print.zusatz(dat = dat2, dat.s = dat.s2, dat.t = dat.t2, 
                   t = "T2",zb = zb, PFAD = PFAD)
    }
    
    
  }
  
  print("Ergebnisse T2 wurden ausgedruckt und gespeichert")
  
}


#-----------------------------------------------------------------------------##
# Ergebnisse T1, T2
if(print.T1 == 1 & print.T2 == 1){
  # EMU-Items
  
  # Bereiche
  bb <- union(unique(dat1$Bereich), unique(dat2$Bereich))
  
  #--------------------------------------------------------
  # Beide MZP: EMU-Skalen
  
  mb <- intersect(bb,bereich)
  lt <- length(mb)
  if(lt > 0){
    
    items <- dat1$Item.Nr[which(dat1$Bereich %in% mb)]
    items2 <- dat2$Item.Nr[which(dat2$Bereich %in% mb)]
    items <- union(items, items2)
    
    # Erstmal ohne Item 26 (Students)
    items <- setdiff(items,"I26s")
    
    mbb <- dat1$Bereich[match(items,dat1$Item.Nr)]
    pp <- which(is.na(mbb))
    if(length(pp)>0){
      mbb[pp] <- dat2$Bereich[match(items[pp],dat2$Item.Nr)]
    }
    lt.items <- sapply(mb, function(x) sum(mbb == x))
    
    itext <- dat1$Itemtext[match(items,dat1$Item.Nr)]
    pp <- which(is.na(itext))
    if(length(pp)>0){
      itext[pp] <- dat2$Itemtext[match(items[pp],dat2$Item.Nr)]
    }
    if(any(is.na(itext))){
      pp <- which(is.na(itext))
      itext[pp] <- dat.t1$Itemtext[match(items[pp],dat.t1$Item.Nr)]
    }
    if(any(is.na(itext))){
      pp <- which(is.na(itext))
      itext[pp] <- dat.t2$Itemtext[match(items[pp],dat.t2$Item.Nr)]
    }
    
    # Abbildung-Name
    pdf.name <- paste0("Abgleich_EMU-Skalen_beider_Messungen__",time,".pdf")
    
    # Grafik speichern
    i26 <- ("I26s" %in% dat1$Item.Nr) | ("I26s"%in% dat2$Item.Nr)
    h <- floor(sum(lt.items)/2) + 3 * (i26)
    pdf(file.path(PFAD,pdf.name),onefile = T,width = 10,height = h)
    
    # Abbilden
    lt1 <- length(grep("M_",names(dat1)))
    lt2 <- length(grep("M_",names(dat2)))
    
    if(!("I26s" %in% dat1$Item.Nr) & !("I26s"%in% dat2$Item.Nr))
      layout(mat = matrix(1:(lt*3),ncol=3,byrow=T),
             widths = c(3,1,1),
             heights = lt.items + 1)
    if(i26)
      layout(mat = matrix(c(1:(lt*3),lt*3 + 1,0,0),ncol=3,byrow=T),
             widths = c(3,1,1),
             heights = c(lt.items + 1,5))
    
    # Abbildung
    for(b in mb){
      # b <- mb[1]
      
      items.b <- items[which(mbb == b)]
      text.b <- itext[match(items.b, items)]
      lt.b <- length(items.b)
      
      # Schüler
      par(xpd=FALSE)
      par(mai = c(0.3,4,0.5,0.2))
      
      plot(x = rep(1:4,lt.b), 
           y = rep(lt.b:1,4), 
           ylim = c(0.5,lt.b+0.5),
           type="n",
           yaxt = "n",xaxt = "n",
           xlab = "",ylab="",cex = 0.5)
      axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
           labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
      par(xpd=T)
      mtext(text = paste0(b),side = 2,line = 2,at = ceiling(lt.b+1),
            font = 2,
            cex = 0.7,las=1)
      
      # Items
      par(xpd=FALSE)
      text.b <- gsub(" $","",text.b)
      text.b1 <- strsplit(text.b,split = " ")
      text <- NULL
      for(i in 1:length(text.b1)){
        string <- text.b1[[i]]
        string <- str_c(string, collapse = " ")
        string <- gsub(" $","",string)
        string <- gsub("\\.$","",string)
        # max length of string <- 60
        num.chars <- nchar(string)
        if(num.chars > 60){
          # find last space before 60
          pp <- strsplit(substr(string,1,60),split = " ")[[1]]
          first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
          last <- gsub(first,"",string)
          last <- gsub("^ ","",last)
          string <- paste0(first,"\n",last)
        }
        text[i] <- string
      }
      
      axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
           cex.axis = 1)
      abline(v = seq(1,4,0.5),col="lightgrey")
      abline(h = c(1:lt.b),col="lightgrey",lty=2)
      
      if("M_S" %in% names(dat1))
        points(x = dat1$M_S[match(items.b,dat1$Item.Nr)],
               y = lt.b:1,type="b",col="orange1",pch = 15,cex = 1.2)
      if("M_S" %in% names(dat2))
        points(x = dat2$M_S[match(items.b,dat2$Item.Nr)],
               y = lt.b:1,type="b",col="orange4",pch = 18,cex = 1)
      par(xpd=TRUE)
      legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
             legend = c("Schüler T1","Schüler T2"),
             pch=c(15,18),lty=2,col=c("orange1","orange4"))
      
      # Lehrer
      par(xpd=FALSE)
      par(mai = c(0.3,0.1,0.5,0.2))
      
      plot(x = rep(1:4,lt.b), 
           y = rep(lt.b:1,4), 
           ylim = c(0.5,lt.b+0.5),
           type="n",
           yaxt = "n",xaxt = "n",
           xlab = "",ylab="",cex = 0.5)
      axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
           labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
      
      abline(v = seq(1,4,0.5),col="lightgrey")
      abline(h = c(1:lt.b),col="lightgrey",lty=2)
      
      if("M_T" %in% names(dat1))
        points(x = dat1$M_T[match(items.b,dat1$Item.Nr)],
               y = lt.b:1,type="b",col="green1",pch = 15,cex = 1.2)
      if("M_T" %in% names(dat2))
        points(x = dat2$M_T[match(items.b,dat2$Item.Nr)],
               y = lt.b:1,type="b",col="green4",pch = 18,cex = 1)
      par(xpd=TRUE)
      legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
             legend = c("Lehrperson T1","Lehrperson T2"),
             pch=c(15,18),lty=2,col=c("green1","green4"))
      
      # Kollegen
      par(xpd=FALSE)
      par(mai = c(0.3,0.1,0.5,0.2))
      
      plot(x = rep(1:4,lt.b), 
           y = rep(lt.b:1,4), 
           ylim = c(0.5,lt.b+0.5),
           type="n",
           yaxt = "n",xaxt = "n",
           xlab = "",ylab="",cex = 0.5)
      axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
           labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
      
      abline(v = seq(1,4,0.5),col="lightgrey")
      abline(h = c(1:lt.b),col="lightgrey",lty=2)
      
      if("M_K" %in% names(dat1))
        points(x = dat1$M_K[match(items.b,dat1$Item.Nr)],
               y = lt.b:1,type="b",col="pink",pch = 15,cex = 1.2)
      if("M_K" %in% names(dat2))
        points(x = dat2$M_K[match(items.b,dat2$Item.Nr)],
               y = lt.b:1,type="b",col="purple3",pch = 18,cex = 1)
      par(xpd=TRUE)
      legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
             legend = c("Kollegen T1","Kollegen T2"),
             pch=c(15,18),lty=2,col=c("pink","purple3"))
      
      
      
    }
    
    # I26s
    if(("I26s" %in% dat1$Item.Nr) | ("I26s"%in% dat2$Item.Nr)){
      par(xpd=FALSE)
      par(mai = c(0.8,2,0.5,0.2))
      mat2 <- mat1 <- NULL
      if("I26s" %in% dat1$Item.Nr){
        mat1 <- dat1[match("I26s",dat1$Item.Nr),
                     c("MZP",paste0("N",1:5,"_S"))]
        M1 <- round(dat1$M_S[match("I26s",dat1$Item.Nr)],1)
        lab.M1 <- paste0("M = ",M1)
      }
      if("I26s" %in% dat2$Item.Nr){
        mat2 <- dat2[match("I26s",dat2$Item.Nr),
                     c("MZP",paste0("N",1:5,"_S"))]
        M2 <- round(dat2$M_S[match("I26s",dat2$Item.Nr)],1)
        lab.M2 <- paste0("M = ",M2)
      }
      mat1 <- rbind(mat1, mat2)
      mat1[,-1] <- round(mat1[,-1] / rowSums(mat1[,-1])*100,1)
      col <- mat1$MZP
      col <- gsub("T1","orange1",col)
      col <- gsub("T2","orange3",col)
      
      colnames(mat1)[-1] <- paste0("N",1:5)
      
      bp1 <- barplot(as.matrix(mat1[,-1]),
                     beside = T,
                     xaxt="n",yaxt="n",
                     border=F,
                     col=col,
                     main = "Der Stoff dieser Unterrichtsstunde\nwar für mich…",
                     cex.main=0.8)
      axis(side = 1,at = seq(2,14,length.out=5),tick = F,
           labels = c("zu\nleicht","etwas zu\nleicht","genau\nrichtig",
                      "etwas zu\nschwierig","zu\nschwierig"),cex.axis = 0.8,
           las = 3)
      max <- max(unlist(mat1[,-1]),na.rm=T)
      par(xpd=T)
      legend(x = 3, y = max+10,cex = 0.8,
             legend = mat1$MZP,col = col,horiz=T,bty="n",fill = col)
      par(xpd=F)
      lab0 <- lab <- (as.matrix(mat1[,-1]))
      # lab[lab == 0] <- NA
      lab1 <- NULL
      for(rr in 1:nrow(lab)) lab1 <- c(lab1, lab[rr,])
      lab1 <- paste0(sprintf("%1.1f",lab1),"%")
      # lab1[lab1 == "NA%"] <- NA
      lab2 <- NULL
      for(rr in 1:nrow(lab0)) lab2 <- c(lab2, lab0[rr,])
      lab2[lab2 == 0] <- 10
      text(x=c(seq(2.2,14.2,length.out=5),seq(3.2,15.2,length.out = 5)),
           y = lab2,
           bp1, labels=as.character(lab1), cex=0.5)
      
    }
    
    dev.off()
  }
  
  
  #--------------------------------------------------------
  # Zusatzskalen
  
  zb <- setdiff(bb,bereich)
  lt <- length(zb)
  
  if(lt > 0){
    
    del.vv <- intersect(c("MZP","N5_S","lnr"),names(dat1))
    dat1a <- dat1[,-match(del.vv,names(dat1))]
    del.vv <- intersect(c("MZP","N5_S","lnr"),names(dat2))
    dat2a <- dat2[,-match(del.vv,names(dat2))]
    names(dat1a)[-c(1:3)] <- paste0("T1_",names(dat1a)[-c(1:3)])
    names(dat2a)[-c(1:3)] <- paste0("T2_",names(dat2a)[-c(1:3)])
    dat <- merge(dat1a, dat2a,all=T)
    
    # Nur Zusatzsitem
    dat <- dat[grep("ZI",dat$Item.Nr),]
    
    dat$lnr <- as.numeric(gsub("ZI","",dat$Item.Nr))
    dat <- dat[order(dat$lnr),]
    
    if(anyDuplicated(dat$Item.Nr)) 
      stop("Bitte Bereichnamen und Item.Nr unter Zusatzbereich in beiden Messungen identisch vergeben.",
           "\nAchten Sie bitte auch die Sonderzeichen inkl. Punkt, Kommas")
    
    
    # Wenn eine  Skala mehr als 40 Items hat, dann trenne es in 3
    # Wenn eine Skala mehr als 20 Items hat, dann trenne es in 2
    # wenn mehrere Skalen weniger als 20 Items hat, 
    # dann Erg. von mehreren Skalen werden in einer Seite gedruckt
    # layout wird variabel erstellt.
    
    # Abbildung-Name
    pdf.name <- paste0("Abgleich_Zusatzbereich_beider_Messungen__",time,".pdf")
    
    items <- dat$Item.Nr[which(dat$Bereich %in% zb)]
    mbb <- dat$Bereich[match(items,dat$Item.Nr)]
    lt.items <- sapply(zb, function(x) sum(mbb == x))
    
    # Neu verteilen anhand Itemuzahl pro Skala
    nitems <- list()
    # Anzahl Skalen mit Itemzahl >= x
    n41 <- sum(lt.items >= 41)
    if(n41 > 0){
      s41 <- names(lt.items)[lt.items >= 41]
      # in 3 teilen
      for(ss in s41){
        s.items <- dat$Item.Nr[which(dat$Bereich == ss)]
        trenn <- floor(length(s.items)/3)
        nitems[[paste0(ss," (Seite 1)")]] <- s.items[1:trenn]
        nitems[[paste0(ss," (Seite 2)")]] <- s.items[(trenn+1):(trenn*2)]
        nitems[[paste0(ss," (Seite 3)")]] <- s.items[(trenn*2+1):length(s.items)]
      }
    }
    n21 <- sum(lt.items >= 21 & lt.items <= 40)
    if(n21 > 0){
      s21 <- names(lt.items)[lt.items >= 21 & lt.items <= 40]
      # in 2 teilen
      for(ss in s21){
        # ss = s21[1]
        s.items <- dat$Item.Nr[which(dat$Bereich == ss)]
        trenn <- floor(length(s.items)/2)
        nitems[[paste0(ss," (Seite 1)")]] <- s.items[1:trenn]
        nitems[[paste0(ss," (Seite 2)")]] <- s.items[(trenn+1):length(s.items)]
      }
    }
    n20 <- sum(lt.items <= 20)
    if(n20 > 0){
      # if Itemzahl insgesamt < 30: alle in einer Seite
      # if Itemzahl insgesamt >= 30: alle in 2 Seiten
      s20 <- names(lt.items)[lt.items <= 20]
      if(sum(lt.items[s20] < 30)){
        s.items <- dat$Item.Nr[which(dat$Bereich %in% s20)]
        nitems[["Rest"]] <- s.items
      } else {
        lt.s20 <- lt.items[s20]
        X <- lt.s20 <- lt.s20[order(lt.s20,decreasing = T)]
        for(ll in 2:length(lt.s20)) X[ll] <- X[ll] + X[ll-1]
        trenn <- ceiling(sum(lt.items[s20])/2)
        pp <- 1*(X <= trenn)
        
        # Gruppe 1
        ss <- names(pp)[pp == 1]
        s.items <- dat$Item.Nr[which(dat$Bereich %in% ss)]
        nitems[["Gruppe 1"]] <- s.items
        
        # Gruppe 2
        ss <- names(pp)[pp == 0]
        s.items <- dat$Item.Nr[which(dat$Bereich %in% ss)]
        nitems[["Gruppe 2"]] <- s.items
      }
    }
    
    # Sind alle Skalen und Items enthalten?
    if(!all(items %in% unlist(nitems))) stop("es fehlen Zusatzitems")
    
    fu <- sapply(1:length(nitems),function(x) nitems[[x]][1])
    nitems <- nitems[order(fu)]
    
    # Grafik speichern
    lt.n <- sapply(1:length(nitems),function(x) length(nitems[[x]]))
    h <- ceiling(max(lt.n)/2) + 1
    
    pdf(file.path(PFAD,pdf.name),onefile = T,width=10, 
        height = h)
    
    # Pro Objekt in nitems eine Seite ausdrucken
    
    for(jj in 1:length(nitems)){
      # jj <- 1
      # Items
      items.jj <- nitems[[jj]]
      
      # Itemformulierung
      itext <- dat$Itemtext[match(items.jj,dat$Item.Nr)]
      
      # Skalen
      sk.jj <- dat$Bereich[match(items.jj,dat$Item.Nr)]
      lt.jj <- length(unique(sk.jj))
      
      # nur eine Skala
      if(lt.jj == 1){
        # Abbilden
        
        items.b <- items.jj
        text.b <- itext[match(items.b, items.jj)]
        lt.b <- length(items.b)
        b <- unique(sk.jj)
        
        # Eine Seite, ine
        layout(mat = matrix(1:3,ncol=3,byrow=T),
               widths = c(3,1,1),heights = lt.b + 1)
        
        # Schüler
        par(xpd=FALSE)
        par(mai = c(0.5,4,0.7,0.2))
        
        plot(x = rep(1:4,lt.b), 
             y = rep(lt.b:1,4), 
             ylim = c(0.5,lt.b+0.5),
             type="n",
             yaxt = "n",xaxt = "n",
             xlab = "",ylab="",cex = 0.5)
        axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
             labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
        par(xpd=T)
        mtext(text = paste0(b),side = 2,line = 2,at = ceiling(lt.b+1),
              font = 2,
              cex = 0.7,las=1)
        
        # Items
        par(xpd=FALSE)
        text.b <- gsub(" $","",text.b)
        text.b1 <- strsplit(text.b,split = " ")
        text <- NULL
        for(i in 1:length(text.b1)){
          string <- text.b1[[i]]
          string <- str_c(string, collapse = " ")
          string <- gsub(" $","",string)
          string <- gsub("\\.$","",string)
          # max length of string <- 60
          num.chars <- nchar(string)
          if(num.chars > 60){
            # find last space before 60
            pp <- strsplit(substr(string,1,60),split = " ")[[1]]
            first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
            last <- gsub(first,"",string)
            last <- gsub("^ ","",last)
            string <- paste0(first,"\n",last)
          }
          text[i] <- string
        }
        
        axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
             cex.axis = 1)
        abline(v = seq(1,4,0.5),col="lightgrey")
        abline(h = c(1:lt.b),col="lightgrey",lty=2)
        
        if("M_S" %in% names(dat1))
          points(x = dat1$M_S[match(items.b,dat1$Item.Nr)],
                 y = lt.b:1,type="b",col="orange1",pch = 15,cex = 1.2)
        if("M_S" %in% names(dat2))
          points(x = dat2$M_S[match(items.b,dat2$Item.Nr)],
                 y = lt.b:1,type="b",col="orange4",pch = 18,cex = 1)
        par(xpd=TRUE)
        legend(x=2.5,y = -0.2,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
               legend = c("Schüler T1","Schüler T2"),
               pch=c(15,18),lty=2,col=c("orange1","orange4"))
        
        # Lehrer
        par(xpd=FALSE)
        par(mai = c(0.5,0.1,0.7,0.2))
        
        plot(x = rep(1:4,lt.b), 
             y = rep(lt.b:1,4), 
             ylim = c(0.5,lt.b+0.5),
             type="n",
             yaxt = "n",xaxt = "n",
             xlab = "",ylab="",cex = 0.5)
        axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
             labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
        
        abline(v = seq(1,4,0.5),col="lightgrey")
        abline(h = c(1:lt.b),col="lightgrey",lty=2)
        
        if("M_T" %in% names(dat1))
          points(x = dat1$M_T[match(items.b,dat1$Item.Nr)],
                 y = lt.b:1,type="b",col="green1",pch = 15,cex = 1.2)
        if("M_T" %in% names(dat2))
          points(x = dat2$M_T[match(items.b,dat2$Item.Nr)],
                 y = lt.b:1,type="b",col="green4",pch = 18,cex = 1)
        par(xpd=TRUE)
        legend(x=2.5,y = -0.2,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
               legend = c("Lehrperson T1","Lehrperson T2"),
               pch=c(15,18),lty=2,col=c("green1","green4"))
        
        # Kollegen
        par(xpd=FALSE)
        par(mai = c(0.5,0.1,0.7,0.2))
        
        plot(x = rep(1:4,lt.b), 
             y = rep(lt.b:1,4), 
             ylim = c(0.5,lt.b+0.5),
             type="n",
             yaxt = "n",xaxt = "n",
             xlab = "",ylab="",cex = 0.5)
        axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
             labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
        
        abline(v = seq(1,4,0.5),col="lightgrey")
        abline(h = c(1:lt.b),col="lightgrey",lty=2)
        
        if("M_K" %in% names(dat1))
          points(x = dat1$M_K[match(items.b,dat1$Item.Nr)],
                 y = lt.b:1,type="b",col="pink",pch = 15,cex = 1.2)
        if("M_K" %in% names(dat2))
          points(x = dat2$M_K[match(items.b,dat2$Item.Nr)],
                 y = lt.b:1,type="b",col="purple3",pch = 18,cex = 1)
        par(xpd=TRUE)
        legend(x=2.5,y = -0.2,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
               legend = c("Kollegen T1","Kollegen T2"),
               pch=c(15,18),lty=2,col=c("pink","purple3"))
        
        
        
      }
      
      # Mehrere Skalen
      if(lt.jj > 1){
        # Abbilden
        
        # Anzahl Items
        jb <- unique(sk.jj)
        lt.jb <- sapply(jb, function(x) sum(sk.jj == x))
        
        # Eine Seite, Mehrere Skala
        layout(mat = matrix(1:(lt.jj*3),ncol=3,byrow=T),
               widths = c(3,1,1),heights = lt.jb + 1)
        
        # Abgleich-Grafik
        for(b in jb){
          # b <- jb[1]
          items.b <- items.jj[sk.jj == b]
          text.b <- itext[match(items.b, items.jj)]
          lt.b <- length(items.b)
          
          # Schüler
          par(xpd=FALSE)
          par(mai = c(0.3,4,0.7,0.2))
          
          plot(x = rep(1:4,lt.b), 
               y = rep(lt.b:1,4), 
               ylim = c(0.5,lt.b+0.5),
               type="n",
               yaxt = "n",xaxt = "n",
               xlab = "",ylab="",cex = 0.5)
          axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
               labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
          par(xpd=T)
          mtext(text = paste0(b),side = 2,line = 2,at = ceiling(lt.b+1),
                font = 2,
                cex = 0.7,las=1)
          
          # Items
          par(xpd=FALSE)
          text.b <- gsub(" $","",text.b)
          text.b1 <- strsplit(text.b,split = " ")
          text <- NULL
          for(i in 1:length(text.b1)){
            string <- text.b1[[i]]
            string <- str_c(string, collapse = " ")
            string <- gsub(" $","",string)
            string <- gsub("\\.$","",string)
            # max length of string <- 60
            num.chars <- nchar(string)
            if(num.chars > 60){
              # find last space before 60
              pp <- strsplit(substr(string,1,60),split = " ")[[1]]
              first <- str_c(pp[1:(length(pp)-1)],collapse=" ")
              last <- gsub(first,"",string)
              last <- gsub("^ ","",last)
              string <- paste0(first,"\n",last)
            }
            text[i] <- string
          }
          
          axis(side = 2,at = c(lt.b:1),labels = text,line = 0,tick=F,las=2,
               cex.axis = 1)
          abline(v = seq(1,4,0.5),col="lightgrey")
          abline(h = c(1:lt.b),col="lightgrey",lty=2)
          
          if("M_S" %in% names(dat1))
            points(x = dat1$M_S[match(items.b,dat1$Item.Nr)],
                   y = lt.b:1,type="b",col="orange1",pch = 15,cex = 1.2)
          if("M_S" %in% names(dat2))
            points(x = dat2$M_S[match(items.b,dat2$Item.Nr)],
                   y = lt.b:1,type="b",col="orange4",pch = 18,cex = 1)
          par(xpd=TRUE)
          legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
                 legend = c("Schüler T1","Schüler T2"),
                 pch=c(15,18),lty=2,col=c("orange1","orange4"))
          
          # Lehrer
          par(xpd=FALSE)
          par(mai = c(0.3,0.1,0.7,0.2))
          
          plot(x = rep(1:4,lt.b), 
               y = rep(lt.b:1,4), 
               ylim = c(0.5,lt.b+0.5),
               type="n",
               yaxt = "n",xaxt = "n",
               xlab = "",ylab="",cex = 0.5)
          axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
               labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
          
          abline(v = seq(1,4,0.5),col="lightgrey")
          abline(h = c(1:lt.b),col="lightgrey",lty=2)
          
          if("M_T" %in% names(dat1))
            points(x = dat1$M_T[match(items.b,dat1$Item.Nr)],
                   y = lt.b:1,type="b",col="green1",pch = 15,cex = 1.2)
          if("M_T" %in% names(dat2))
            points(x = dat2$M_T[match(items.b,dat2$Item.Nr)],
                   y = lt.b:1,type="b",col="green4",pch = 18,cex = 1)
          par(xpd=TRUE)
          legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
                 legend = c("Lehrperson T1","Lehrperson T2"),
                 pch=c(15,18),lty=2,col=c("green1","green4"))
          
          # Kollegen
          par(xpd=FALSE)
          par(mai = c(0.3,0.1,0.7,0.2))
          
          plot(x = rep(1:4,lt.b), 
               y = rep(lt.b:1,4), 
               ylim = c(0.5,lt.b+0.5),
               type="n",
               yaxt = "n",xaxt = "n",
               xlab = "",ylab="",cex = 0.5)
          axis(side = 3,at = seq(1,4,0.5),cex.axis = 0.8,
               labels = c("stimme\nnicht zu",seq(1.5,3.5,0.5),"stimme\nzu"))
          
          abline(v = seq(1,4,0.5),col="lightgrey")
          abline(h = c(1:lt.b),col="lightgrey",lty=2)
          
          if("M_K" %in% names(dat1))
            points(x = dat1$M_K[match(items.b,dat1$Item.Nr)],
                   y = lt.b:1,type="b",col="pink",pch = 15,cex = 1.2)
          if("M_K" %in% names(dat2))
            points(x = dat2$M_K[match(items.b,dat2$Item.Nr)],
                   y = lt.b:1,type="b",col="purple3",pch = 18,cex = 1)
          par(xpd=TRUE)
          legend(x=2.5,y = 0.25,bty = "n" ,horiz=T,cex = 0.9,xjust = 0.5,
                 legend = c("Kollegen T1","Kollegen T2"),
                 pch=c(15,18),lty=2,col=c("pink","purple3"))
          
        }
        
        
        
      }
      
    }
    
    dev.off()
    
  }
  
  
  print("Ergebnisse T1 & T2 wurden ausgedruckt und gespeichert")
  

}
